Changes
=======

3.0 (2021-02-10)
----------------

- Add support for Python 3.5, 3.6, 3.7, 3.8 and 3.9.


2.0 (2007-08-23)
----------------

- Add the ``PostMortemDebug`` (pdb) middleware.

1.0 (2007-06-02)
----------------

- Initial release, featuring the Zope 3-compatible interactive AJAX
  debugger from Paste.
